/*
 * Copyright 1994, 1995 Vectaport Inc., Cartoactive Systems
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

/* Class wrapper for vpf library object */

#ifndef vpflib_h
#define vpflib_h

#include <Map/maplib.h>
#include <Vpf/vpf.h>

class VpfCoverage;
class VpfDatabase;

class VpfLibrary : public MapLibrary {
public:
    VpfLibrary (VpfDatabase*, const char* name);
    virtual ~VpfLibrary ();

    virtual const char* path() const;
    VpfDatabase* database() const { return (VpfDatabase*)_database; }
    virtual void database(VpfDatabase* db);
 
    VpfCoverage* coverage(int covnum) const;
    VpfCoverage* coverage(const char*) const;

    virtual const char* description() const;

    VpfExtent* extent() const;

    void print() const;

    boolean gazette();
    int gazette_search(const char* name, char**& matches, char**& types,
		       float*& posx, float*& posy);
    void gaz_tileindex();
protected:
    virtual char** coverage_names (int& ncovs) const;
    virtual MapCoverage* make_coverage(const char* name);

protected:
    char* _desc;
};

#endif /* defined(vpflib_h) */
