/*
 * Copyright 1995 Vectaport Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

/*
 * VpfKit - object to construct objects for an VpfEditor
 */

#ifndef vpf_kit_h
#define vpf_kit_h

#include <MapUnidraw/mapkit.h>
#include <OS/table.h>

#include <InterViews/_enter.h>

class Dialog;
class VpfGazetteer;
class VpfFeatureClass;
class MenuItem;

declareTable(VpfFClassMenuTable,VpfFeatureClass*,MenuItem*)
declareTable(VpfFClassTable,VpfFeatureClass*,boolean)

class VpfKit : public MapKit {
public:
    VpfKit();
    virtual ~VpfKit();

    virtual void InitMembers(OverlayComp*);
    virtual MenuItem* MakeFileMenu();
    virtual MenuItem* MakeViewMenu();
    virtual MenuItem* MakeMapMenu();
    virtual Glyph* MakeMenus();
    virtual Glyph* MakeToolbar();

    MenuItem* GetLayerMenu() { return _layermenu; }
    MenuItem* GetLibraryMenu() { return _libmenu; }
    virtual void UpdateLayerMenu();
    virtual void UpdateLibraryMenu();
    void FClassState(VpfFeatureClass*, boolean);

    void gaz();

    static VpfKit* Instance();

    void toolbar0();
    void toolbar1();
    void ExplainTileSel(char*);
    void tiledismiss();
protected:
    void MakeCheckMenu(MenuItem*, Command*, Command*, const char*,
		       VpfFeatureClass*);
    MenuItem* MakeLayerMenus();
    MenuItem* MakeShowLayerMenus();
    MenuItem* MakeHideLayerMenus();
    MenuItem* MakeLibraryMenu();
    MenuItem* _layermenu;
    MenuItem* _showlayermenu;
    MenuItem* _hidelayermenu;
    MenuItem* _libmenu;
    MenuItem* _mapmenu;
    VpfFClassMenuTable* _fcmenutable;
    VpfFClassTable* _fctable;
    static VpfKit* _vpfkit;
    VpfGazetteer* _vpfgaz;
    Dialog* _tiledialog;
};

class VpfTileKit : public VpfKit {
public:
    VpfTileKit();

    virtual MenuItem* MakeMapMenu();
    virtual Glyph* MakeStates();

    static VpfTileKit* Instance();
protected:
    static VpfTileKit* _vpftilekit;
};

#include <InterViews/_leave.h>

#endif

